@@ -9,7 +9,7 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.32_07';
+$VERSION = '0.32_08';
 
 %EXPORT_TAGS = (
     'all' => [qw(
@@ -61,7 +61,9 @@ UUID - Universally Unique Identifier library for Perl
 
 =head1 SYNOPSIS
 
-    use UUID qw(uuid uuid1 uuid4);    # see EXPORTS
+    use UUID qw(uuid);    # see EXPORTS
+
+    my $str = uuid();     # generate version 4 UUID string
 
     $str = uuid();                    # new stringified UUID; prefer v4
     $str = uuid1();                   # new stringified UUID; always v1
@@ -108,18 +110,22 @@ system, and unique across all systems, and are compatible with those
 created by the Open Software Foundation (OSF) Distributed Computing
 Environment (DCE).
 
-All generated UUIDs are either version 1 or version 4. And all are
-variant 1, meaning compliant with the OSF DCE standard as described
+All generated UUIDs are either version 1, 4, 6, or version 7. And all
+are variant 1, meaning compliant with the OSF DCE standard as described
 in RFC4122.
 
+Versions 6, 7, and 8 are not standardized. They are presented here as
+proposed in RFC4122bis, version 14, and may change in the future.
+RFC4122bis is noted to replace RFC4122, if approved.
+
 =head1 FUNCTIONS
 
 Most of the UUID functions expose the historically underlying
 I<libuuid> C interface rather directly. That is, many return their
 values in their parameters and nothing else.
 
-Not very Perlish, is it? It's been like that for a long time now,
-so not likely to change any time soon.
+Not very Perlish, but it's been like that for a long time so not likely
+to change any time soon.
 
 All take or return UUIDs in either binary or string format. The string
 format resembles the following:
@@ -134,7 +140,7 @@ The binary form is simply a packed 16 byte binary value.
 
 =head2 B<clear(> I<$uuid> B<)>
 
-Sets I<$uuid> equal to the value of the NULL UUID.
+Sets binary I<$uuid> equal to the value of the NULL UUID.
 
 =head2 B<compare(> I<$uuid1>B<,> I<$uuid2> B<)>
 
@@ -143,7 +149,10 @@ Compares two binary UUIDs.
 Returns an integer less than, equal to, or greater than zero if
 I<$uuid1> is less than, equal to, or greater than I<$uuid2>.
 
-However, if either operand is not a UUID, falls back to a simple string
+If one is defined and the other not, the defined value is deemed the
+larger.
+
+If either operand is not a binary UUID, falls back to a simple string
 comparison returning similar values.
 
 =head2 B<copy(> I<$dst>B<,> I<$src> B<)>
@@ -154,31 +163,23 @@ If I<$src> isn't a UUID, I<$dst> is set to the NULL UUID.
 
 =head2 B<generate(> I<$uuid> B<)>
 
-Generates a new version 4 binary UUID based on high quality randomness
-from I</dev/urandom> or I</dev/random>, if available.
+Alias for B<generate_v4()>.
 
-If not, a new version 1 binary UUID is returned.
-
-The previous content of I<$uuid>, if any, is lost.
+Prior to version 0.33, this function provided either a binary version 4
+UUID or fell back to version 1 in some cases. This is no longer the
+case. The fallback feature was removed with the addition of an onboard
+crypto-strength number generator.
 
 =head2 B<generate_random(> I<$uuid> B<)>
 
-Generates a new version 4 binary UUID even if a high-quality random
-number generator (e.g., I</dev/urandom>) is not available, in which case
-a pseudo-random generator is used.
-
-Note that the use of a pseudo-random generator may compromise the
-uniqueness of UUIDs generated in this fashion.
-
-If I</dev/urandom> and/or I</dev/random> are present, the system calls
-I<get_random()> and/or I<get_entropy()> are used first, if available.
-
-If the system calls are not available, randomness is read directly from
-the random devices, preferring I</dev/urandom> but falling back to
-I</dev/random> in non-blocking mode.
+Alias for B<generate_v4()>.
 
 =head2 B<generate_time(> I<$uuid> B<)>
 
+Alias for B<generate_v1()>.
+
+=head2 B<generate_v1(> I<$uuid> B<)>
+
 Generates a new version 1 binary UUID using the current time and the
 local ethernet MAC address, if available.
 
@@ -187,17 +188,32 @@ is requested (see B<:mac> in B<EXPORTS>), a random address is used. The
 multicast bit of this address is set to avoid conflict with addresses
 returned from network cards.
 
-This algorithm used to be the default for generating UUIDs, but because
-of privacy concerns, the B<generate()> function only uses it if a
-high-quality source of randomness is not available.
-
-=head2 B<generate_v1(> I<$uuid> B<)>
-
-Alias for B<generate_time()>.
-
 =head2 B<generate_v4(> I<$uuid> B<)>
 
-Alias for B<generate_random()>.
+Generates a new version 4 binary UUID using mostly random data. There
+are 6 bits used for the UUID format, leaving 122 bits for randomness.
+
+=head2 B<generate_v6(> I<$uuid> B<)>
+
+Generates a new version 6 binary UUID using the current time and the
+local ethernet MAC address, if available.
+
+If the MAC address is not available at startup, or a randomized address
+is requested (see B<:mac> in B<EXPORTS>), a random address is used. The
+multicast bit of this address is set to avoid conflict with addresses
+returned from network cards.
+
+Version 6 is the same as version 1, with reversed time fields to make it
+more database friendly.
+
+=head2 B<generate_v7(> I<$uuid> B<)>
+
+Generates a new version 7 binary UUID using the current time and random
+data. There are 6 bits used for the UUID format and 48 bits for
+timestamp, leaving 74 bits for randomness.
+
+Version 7 is the same as version 6, in that it uses reversed timestamp
+fields, but also uses a Unix epoch time base instead of Gregorian.
 
 =head2 B<is_null(> I<$uuid> B<)>
 
@@ -218,53 +234,54 @@ content of I<$uuid> is unchanged.
 Returns the time element of a binary UUID in seconds since the epoch,
 the same as I<Perl>'s B<time> function.
 
-Keep in mind this only works for type 1 UUIDs. Values returned from
-other types range from non-standardized to totally random.
+Keep in mind this only works for version 1, 6, and version 7 UUIDs.
+Values returned from other versions are always 0.
 
 =head2 B<type(> I<$uuid> B<)>
 
-Returns the type of binary I<$uuid>.
-
-This module only generates type 1 (time) and type 4 (random) UUIDs, but
-others may be found in the wild.
-
-Known types:
-    1  a.k.a. Version 1 - date/time and MAC address
-    2  a.k.a. Version 2 - date/time and MAC address, security version
-    3  a.k.a. Version 3 - namespace based, MD5 hash
-    4  a.k.a. Version 4 - random
-    5  a.k.a. Version 5 - namespace based, SHA-1 hash
+Alias for B<version()>.
 
 =head2 B<unparse(> I<$uuid>B<,> I<$string> B<)>
 
+Alias for B<unparse_lower()>.
+
+Prior to version 0.32, casing of the return value was system-dependent.
+Later versions are lowercase, per RFC4122.
+
+=head2 B<unparse_lower(> I<$uuid>B<,> I<$string> B<)>
+
 Converts the binary UUID in I<$uuid> to string format and returns in
 I<$string>. The previous content of I<$string>, if any, is lost.
 
-Prior to version 0.32, casing of the return value was system-dependent.
-Later versions are lower case, per RFC4122.
-
-=head2 B<unparse_lower(> I<$uuid>B<,> I<$string> B<)>
-
-Same as B<unparse()>.
-
 =head2 B<unparse_upper(> I<$uuid>B<,> I<$string> B<)>
 
-Same as B<unparse()> but I<$string> is forced to upper case.
+Same as B<unparse_lower()> but I<$string> is forced to upper case.
 
 =head2 B<uuid()>
 
-Creates a new string format UUID and returns it in a more Perlish way.
+Alias for B<uuid4()>.
 
-Functionally the equivalent of calling B<generate()> and then B<unparse()>, but
-throwing away the intermediate binary UUID.
+=head2 B<uuid0()>
+
+Returns a new string format NULL UUID.
 
 =head2 B<uuid1()>
 
-Same as B<uuid()> but always version 1.
+Returns a new string format version 1 UUID. Functionally the equivalent
+of calling B<generate_v1()> then B<unparse()>, but throwing away the
+intermediate binary UUID.
 
 =head2 B<uuid4()>
 
-Same as B<uuid()> but always version 4.
+Same as B<uuid1()> but version 4.
+
+=head2 B<uuid6()>
+
+Same as B<uuid1()> but version 6.
+
+=head2 B<uuid7()>
+
+Same as B<uuid1()> but version 7.
 
 =head2 B<variant(> I<$uuid> B<)>
 
@@ -282,48 +299,85 @@ Known variants:
 
 =head2 B<version(> I<$uuid>> B<)>
 
-Alias for B<type()>.
+Returns the version of binary I<$uuid>.
+
+This module only generates version 1, 4, 6, and version 7 UUIDs, but
+others may be found in the wild.
+
+Known versions:
+    v1  date/time and node address
+    v2  date/time and node address, security version
+    v3  namespace based, MD5 hash
+    v4  random
+    v5  namespace based, SHA-1 hash
+    v6  reverse date/time and node address
+    v7  reverse unix date/time and random
+    v8  custom
 
 =head1 MAINTAINING STATE
 
-Internal state is optionally maintained for version 1 UUIDs via a file
-designated by the B<:persist> export tag (see EXPORTS), if the path
-exists and the user running the process has read/write permission.
-
-If the file doesn't exist, it is created if the directory path
-exists.
+Internal state is optionally maintained for timestamped UUIDs (versions
+1, 6, and 7) via a file designated by the B<:persist> export tag. See
+B<EXPORTS> for details.
 
 The file records various internal states at the time the last UUID is
 generated, preventing future instances from overlapping the prior UUID
 sequence. This allows the sequence to absolutely survive reboots and,
 more importantly, backwards resetting of system time.
 
-If B<:persist> is not used, time resets will still be detected while
-the module is loaded and handled accordingly. And since startup in
-this case is randomized anyway, the chance of overlap is low but
-still exists. The randomized clock_seq field is 14 bits wide.
+If B<:persist> is not used, time resets will still be detected while the
+module is loaded and handled by incrementing the UUID clock_seq field.
+The clock_seq field is randomly initialized in this case anyway, so the
+chance of overlap is low but still exists since clock_seq is only 14
+bits wide. Using a random MAC will help (see B<:mac> in B<EXPORTS>),
+adding an additional 48 bits of randomness.
 
-Note that use of this feature incurs a serious performance penalty,
-upwards of 90% on tested platforms.
+B<NOTE:> Using B<:persist> incurs a serious performance penalty, in
+excess of 95% on tested platforms. You can run C<make compare> in the
+distribution directory to see how this might affect your application,
+but unless you need many thousands of UUIDs/sec it's probably a
+non-issue.
 
-Note too that use of a random MAC greatly reduces the chance of
-overlap. The randomized fields total 62 bits at start.
+=head1 RANDOM NUMBERS
+
+Prior to version 0.33, UUID obtained randomness from the system's
+I</dev/random> device, or similar interface. On some platforms it called
+B<getrandom()> and on others it read directly from I</dev/urandom>. And
+of course, Win32 did something completely different depending on the
+environment.
+
+Starting in 0.33, UUID generates random numbers itself using the
+ChaCha20 algorithm, which is considered crypto-strength in most circles.
+This is the same algo used as the basis for many modern kernel RNGs,
+albeit without the same entropy gathering ability.
+
+To compensate, UUID mixes the output from ChaCha with output from
+another RNG, Xoshiro. The theory is that by mixing the two, the true
+output from either is effectively hidden, making discovery of either's
+key much more unlikely than it already is. And without the keys, you
+can't predict the future.
+
+Well, that's the theory anyway.
 
 =head1 EXPORTS
 
 None by default. All functions may be imported in the usual manner,
 either individually or all at once using the B<:all> tag.
 
+Beware that importing B<:all> clobbers I<Perl>'s B<time()>, not to
+mention a few other commonly used subs, like B<copy()> from
+I<File::Copy>.
+
 =head2 B<:mac>=I<mode>
 
-The MAC address used for v1 UUIDS is forced to always be random in
-one of two modes:
+The MAC address used for MAC-inclusive UUIDS (versions 1 and 6) is
+forced to always be random in one of two modes:
 
 =over 4
 
-I<random> The MAC address is generated once at startup and used
-throughout the lifetime of the process. This is the default if the real
-MAC cannot be found.
+I<random> The MAC address is generated once at startup and used through
+the lifetime of the process. This is the default if a real MAC cannot be
+found.
 
 I<unique> A new MAC address is generated for each new UUID. It is not
 guaranteed to be unique beyond the probability of randomness.
@@ -332,7 +386,7 @@ guaranteed to be unique beyond the probability of randomness.
 
 =head2 B<:persist>=F<path/to/state.txt>
 
-Path to version 1 state maintenance file. (See B<MAINTAINING STATE>.)
+Path to timestamp state maintenance file. (See B<MAINTAINING STATE>.)
 The path may be either relative or absolute.
 
 If the file does not exist, it will be created provided the path
@@ -395,10 +449,10 @@ twata
 
 =head1 SEE ALSO
 
-RFC4122
+B<RFC4122> - L<https://www.rfc-editor.org/rfc/rfc4122>
 
-B<uuid(3)>, B<uuid_clear(3)>, B<uuid_compare(3)>, B<uuid_copy(3)>,
-B<uuid_generate(3)>, B<uuid_is_null(3)>, B<uuid_parse(3)>,
-B<uuid_unparse(3)>, B<perl(1)>.
+B<RFC4122bis> - L<https://www.ietf.org/archive/id/draft-ietf-uuidrev-rfc4122bis-14.html>
+
+B<perl(1)>.
 
 =cut
