@@ -56,7 +56,7 @@ sub generate_conf {
             HAVE_STRING_H        string.h
             HAVE_SYS_FILE_H      sys/file.h
             HAVE_SYS_IOCTL_H     sys/ioctl.h
-            HAVE_SYS_RANDOM_H    sys/random.h
+            -HAVE_SYS_RANDOM_H    sys/random.h
             HAVE_SYS_RESOURCE_H  sys/resource.h
             HAVE_SYS_SOCKET_H    sys/socket.h
             HAVE_SYS_SOCKIO_H    sys/sockio.h
@@ -80,7 +80,7 @@ sub generate_conf {
         try_precise      ($check, \$longest, $defines);
         try_sa_len       ($check, \$longest, $defines);
         try_symlink      ($check, \$longest, $defines);
-        try_threads      ($check, \$longest, $defines);
+        #try_threads      ($check, \$longest, $defines);
 
         # do this last, just to be safe.
         try_u64          ($check, \$longest, $defines);
