@@ -1,7 +1,7 @@
 #ifndef UU_CHACHA_H
 #define UU_CHACHA_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void cc_srand(void);
 
