@@ -1,18 +1,19 @@
 #ifndef UU_GEN_H
 #define UU_GEN_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
-void uu_v1gen_init();
-void uu_v1set_rand();
-void uu_v1set_uniq();
+void uu_gen_init();
+void uu_gen_setrand();
+void uu_gen_setuniq();
+
+int uu_realnode(struct uu *out);
 
 void uu_v0gen(struct uu *out);
 void uu_v1gen(struct uu *out);
 void uu_v4gen(struct uu4 *out);
 void uu_v6gen(struct uu6 *out);
 void uu_v7gen(struct uu7 *out);
-void uu_vXgen(struct uu *out);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
