@@ -1,5 +1,13 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/gettime.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 #ifdef USE_WIN32_NATIVE
 int gettimeofday(struct timeval * tv, struct timezone * tz) {
   /* Note: SYSTEMTIME has 1ms resolution.
