@@ -1,7 +1,7 @@
 #ifndef UU_GETTIME_H
 #define UU_GETTIME_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 #ifdef USE_WIN32_NATIVE
 #ifndef HAVE_GETTIMEOFDAY
