@@ -1,11 +1,19 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/isnull.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 IV uu_isnull_binary(const uu_t in)
 {
   const U8  *cp = in;
   IV        i;
 
-  for (i=0; i<16; i++)
+  for (i=0; i<sizeof(uu_t); i++)
     if (*cp++)
       return 0;
   return 1;
