@@ -1,7 +1,7 @@
 #ifndef UU_ISNULL_H
 #define UU_ISNULL_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 IV uu_isnull_binary(const uu_t in);
 IV uu_isnull_struct(const struct uu *in);
