@@ -1,7 +1,7 @@
 #ifndef UU_PACK_H
 #define UU_PACK_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void uu_pack(const struct uu *in, uu_t out);
 void uu_pack4(const struct uu4 *in, uu_t out);
