@@ -1,5 +1,13 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/parse.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 IV uu_parse(const char *in, struct uu *out) {
   int         i;
   const char  *cp;
