@@ -1,7 +1,7 @@
 #ifndef UU_PARSE_H
 #define UU_PARSE_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 IV uu_parse(const char *in, struct uu *out);
 
