@@ -1,7 +1,7 @@
 #ifndef UU_SPLITMIX_H
 #define UU_SPLITMIX_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void sm_srand(void);
 U64  sm_rand(void);
