@@ -1,7 +1,7 @@
 #ifndef UU_UNPACK_H
 #define UU_UNPACK_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void uu_unpack(const uu_t in, struct uu *out);
 
