@@ -1,5 +1,13 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "uulib/unparse.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 static const char *fmt_lower = "0123456789abcdef";
 static const char *fmt_upper = "0123456789ABCDEF";
 
