@@ -1,7 +1,7 @@
 #ifndef UU_UNPARSE_H
 #define UU_UNPARSE_H
 
-#include "uulib/CONF.h"
+#include "uulib/UUID.h"
 
 void uu_unparse_lower(const struct uu *in, char *out);
 void uu_unparse_upper(const struct uu *in, char *out);
